@@ -24,8 +24,9 @@ class SingularClient(object):
     BASE_API_URL = "https://api.singular.net/api/"
     DEFAULT_HTTP_TIMEOUT = 60 * 5
 
-    def __init__(self, api_key, http_timeout=DEFAULT_HTTP_TIMEOUT):
+    def __init__(self, api_key, http_timeout=DEFAULT_HTTP_TIMEOUT, user_agent='Singular API Client v%s' % __version__):
         self.api_key = api_key
+        self.user_agent = user_agent
         session = requests.Session()
         retry = Retry(
             connect=5,
@@ -39,61 +40,6 @@ class SingularClient(object):
         self.default_http_timeout = http_timeout
         self.session = session
 
-    def run_report(self, start_date, end_date,
-                   format=Format.JSON,
-                   dimensions=(Dimensions.APP, Dimensions.OS, Dimensions.SOURCE),
-                   metrics=(Metrics.ADN_COST, Metrics.ADN_IMPRESSIONS),
-                   discrepancy_metrics=(DiscrepancyMetrics.ADN_CLICKS, DiscrepancyMetrics.ADN_INSTALLS),
-                   cohort_metrics=None,
-                   cohort_periods=None,
-                   source=None,
-                   app=None,
-                   display_alignment=True,
-                   time_breakdown=TimeBreakdown.ALL,
-                   country_code_format=CountryCodeFormat.ISO3,
-                   filters=None,
-                   **kwargs
-                   ):
-        """
-        Use this endpoint to run custom queries in the Singular platform for aggregated statistics.
-          We recommend create_async_report for production ETL process
-
-        :param start_date: "YYYY-mm-dd" format date
-        :param end_date: "YYYY-mm-dd" format date
-        :param format: Format for returned results, for example Format.CSV
-        :param dimensions: A list of dimensions, for example [Dimensions.APP, Dimensions.Source]
-        :param metrics: A list of metrics, for example [Metrics.ADN_IMPRESSIONS, Metrics.ADN_COST]
-        :param discrepancy_metrics: List of metrics that may help detect discrepancies between Ad Networks
-          and Attribution providers, for example [DiscrepancyMetrics.ADN_CLICKS, DiscrepancyMetrics.ADN_INSTALLS]
-        :param cohort_metrics: list of cohorted metrics by name or ID; A full list can be retrieved through
-          the Cohorted Metrics endpoint
-        :param cohort_periods: list of cohorted periods; A full list can be retrieved through the Cohorted Metrics
-          endpoint
-        :param source: optional list of source names to filter by
-        :param app: optional list of app names to filter by
-        :param display_alignment: When set to True, results will include an alignment row to account for any difference
-         between campaign and creative statistics
-        :param time_breakdown: Break results by the requested time period, for example TimeBreakdown.DAY
-        :param country_code_format: Country code formatting option, for example CountryCodeFormat.ISO3
-        :param filters: a JSON encoded list of filters. Can be used to apply more complex filters than simply filtering
-          by app or source. The relation between different elements of the list is an AND relation.
-          A full list of the dimensions you can filter by and potential values can be retrieved from the
-          `get_reporting_filters` endpoint.
-        :return: parsed JSON response dict if format is Format.JSON or unicode if format is Format.CSV
-        """
-        query_dict = self._build_reporting_query(start_date, end_date, format, dimensions, metrics,
-                                                 discrepancy_metrics, cohort_metrics, cohort_periods, app,
-                                                 source, display_alignment, time_breakdown, country_code_format,
-                                                 filters, **kwargs)
-        response = self._api_get("v2.0/reporting", params=query_dict)
-        if format == Format.JSON:
-            self._verify_legacy_error(response.json())
-            return response.json()
-        elif format == Format.CSV:
-            return response.text
-        else:
-            raise ArgumentValidationException("unsupported format")
-
     def create_async_report(self, start_date, end_date,
                             format=Format.JSON,
                             dimensions=(Dimensions.APP, Dimensions.OS, Dimensions.SOURCE),
@@ -146,6 +92,47 @@ class SingularClient(object):
         parsed_response = response.json()
         return parsed_response["value"]["report_id"]
 
+    def create_async_skadnetwork_raw_report(self, start_date, end_date,
+                                            format=Format.JSON,
+                                            dimensions=(Dimensions.APP, Dimensions.SOURCE,
+                                                        Dimensions.SKAN_CAMPAIGN_ID, Dimensions.SKAN_CONVERSION_VALUE),
+                                            metrics=(Metrics.SKAN_INSTALLS,),
+                                            source=None,
+                                            app=None,
+                                            time_breakdown=TimeBreakdown.ALL,
+                                            country_code_format=CountryCodeFormat.ISO3,
+                                            filters=None,
+                                            **kwargs
+                                            ):
+        """
+        Use this endpoint to run custom queries in the Singular platform for aggregated skadnetwork raw data without
+         keeping a live connection throughout the request
+
+        :param start_date: "YYYY-mm-dd" format date
+        :param end_date: "YYYY-mm-dd" format date
+        :param format: Format for returned results, for example Format.CSV
+        :param dimensions: A list of dimensions, for example [Dimensions.APP, Dimensions.Source, Dimensions.SKAN_CAMPAIGN_ID]
+        :param metrics: A list of metrics, for example [Metrics.SKAN_INSTALLS]
+        :param source: optional list of source names to filter by
+        :param app: optional list of app names to filter by
+        :param time_breakdown: Break results by the requested time period, for example TimeBreakdown.DAY
+        :param country_code_format: Country code formatting option, for example CountryCodeFormat.ISO3
+        :param filters: a JSON encoded list of filters. Can be used to apply more complex filters than simply filtering
+          by app or source. The relation between different elements of the list is an AND relation.
+          A full list of the dimensions you can filter by and potential values can be retrieved from the
+          `get_reporting_filters` endpoint.
+        :return: report_id
+        """
+
+        query_dict = self._build_reporting_query(start_date, end_date, format, dimensions, metrics,
+                                                 [], None, None, app,
+                                                 source, None, time_breakdown, country_code_format,
+                                                 filters, **kwargs)
+
+        response = self._api_post("v2.0/create_async_skadnetwork_raw_report", data=query_dict)
+        parsed_response = response.json()
+        return parsed_response["value"]["report_id"]
+
     def get_report_status(self, report_id):
         """
         This endpoint returns the status of a given report.
@@ -187,27 +174,6 @@ class SingularClient(object):
         self._verify_legacy_error(parsed_response)
         return CohortMetricsResponse(parsed_response["value"])
 
-    def get_last_modified_dates(self, utc_timestamp, group_by_source=True):
-        """
-        Use this endpoint to detect retroactive data changes by source and date, to run narrowed-down queries
-          using filters that only pull the modified data
-
-        :param utc_timestamp: The UTC timestamp when you last pulled data from Singular,
-            formatted as "YYYY-mm-dd HH:mm:SS"
-        :type utc_timestamp: str
-        :param group_by_source: When set to `True`, results will be grouped by source
-        :type group_by_source: bool
-        :return: List of modified dates, or dict(Network-->List of modified dates) if group_by_source=True
-        :rtype: dict[str, list[str]]
-        """
-
-        query_dict = dict(timestamp=utc_timestamp, group_by_source=self._bool(group_by_source))
-
-        response = self._api_get("last_modified_dates", params=query_dict)
-        parsed_response = response.json()
-        self._verify_legacy_error(parsed_response)
-        return parsed_response["value"]["results"]
-
     def data_availability_status(self, data_date, format=Format.JSON, display_non_active_sources=False):
         """
         Use this endpoint to determine whether for a given day, data is available for each of your data data sources.
@@ -357,7 +323,7 @@ class SingularClient(object):
     def _api_request(self, method, endpoint, **kwargs):
         url = self.BASE_API_URL + endpoint
         headers = {"Authorization": self.api_key,
-                   'User-Agent': 'Singular API Client v%s' % __version__}
+                   'User-Agent': self.user_agent}
 
         response = self.session.request(method, url,
                                         headers=headers,
